import  {
  select, 
  csv, 
  scaleLinear, 
  extent,
  axisLeft, 
  axisBottom,
  format
} from 'd3';
const svg = select("svg");
const width = +svg.attr("width"),
      height = +svg.attr("height");

const render = data => {
  const xValue = d => d.horsepower;
  const xAxisLabel = "Horsepower";
  const yValue = d => d.weight;
  const yAxisLabel = "Weight";
  const circleRadius = 8  
  const title = "Cars: HorsePower vs. Weight";
  const margin = { top: 80, left: 130, bottom: 65, right: 40}
  const innerWidth = width - margin.left - margin.right; 
  const innerHeight = height - margin.top - margin.bottom;
  
  const xScale = scaleLinear()
  	.domain(extent(data, xValue))
  	.range([0, innerWidth])
  	.nice()
  
  const yScale = scaleLinear()
  	.domain(extent(data, yValue))
  	.range([innerHeight, 0])
  	.nice()
  
  const xAxis = axisBottom(xScale)
  	.tickSize(-innerHeight)
  	.tickPadding(10)
  
  const yAxis = axisLeft(yScale)
  	.tickSize(-innerWidth)
  	.tickPadding(10)
  
  const g = svg.append("g")
  	.attr("transform", `translate(${margin.left}, ${margin.top})`)
  
  const yAxisG = g.append("g").call(yAxis)
	yAxisG.selectAll(".domain").remove();
  yAxisG.append("text")
  	.attr("class", "axis-label")
  	.attr('x', -innerHeight / 2)
  	.attr('y', -80)
  	.attr('transform', "rotate(-90)")
  	.attr('text-anchor', 'middle')
  	.attr('fill', 'black')
  	.text(yAxisLabel);
  	
  const xAxisG = g.append("g").call(xAxis)
  	.attr("transform", `translate(0, ${innerHeight})`);
  
  xAxisG.selectAll(".domain").remove();
  
  xAxisG.append("text")
  	.attr("class", "axis-label")
  	.attr('y', 55)
  	.attr('x', innerWidth / 2)
  	.attr('fill', 'black')
  	.text(xAxisLabel);
  
  g.selectAll("circle")
  	.data(data)
  	.enter().append("circle")
  	.attr("cy", d => yScale(yValue(d)))
  	.attr("cx", d => xScale(xValue(d)))
  	.attr("r", circleRadius)
  	.attr("opacity", 0.5);
    
  svg.append("text")
  	.attr("y", 50)
  	.attr("x", width / 2)
  	.attr("text-anchor", "middle")
  	.text(title)
}

csv('https://vizhub.com/curran/datasets/auto-mpg.csv')
	.then(
  data => {
    data.forEach(d => {
      d.mpg = +d.mpg;
      d.cylinders = +d.cylinders;
      d.displacement = +d.displacement;
      d.horsepower = +d.horsepower;
      d.weight = +d.weight;
      d.acceleration = +d.acceleration;
      d.year = +d.year;
    });
    render(data);
  })